@@ -64,7 +64,7 @@ extern int cont_indent, fld_indent, newline_indent, max_linelen;
 extern char *actual_path;
 extern UserDefFld userDefFlds[];
 extern PredefLists predefLst;
-extern listEntry list_layout;
+extern listEntry *list_layout;
 
 
 
@@ -262,7 +262,7 @@ int i;
                  "BibView",                   /* Appl class */
                  optionDesc,                  /* cmdline options */ 
 		 XtNumber(optionDesc),
-                 &argc, argv,                 /* command line args */
+                 &argc, argv,     /* command line args */
                  (String *)fallback_resources,/* fallback resources */
 		 NULL);                       /* end varargs list */
    
@@ -482,20 +482,21 @@ int i, j;
    
    max_fields = 25;
    max_bibtex_types = 14;
-
-   list_layout.number = 0;
-   list_layout.field[list_layout.number] = nauthor;
-   list_layout.width[list_layout.number++] = 30;
-   list_layout.field[list_layout.number] = ntitle; 
-   list_layout.width[list_layout.number++] = 50;
-   list_layout.field[list_layout.number] = nyear; 
-   list_layout.width[list_layout.number++] = 5;
-   list_layout.field[list_layout.number] = ncategory; 
-   list_layout.width[list_layout.number++] = 10;
-   list_layout.field[list_layout.number] = -2;  /* BibTeX type */
-   list_layout.width[list_layout.number++] = 10;
-   list_layout.field[list_layout.number] = -1;  /* mainkey */
-   list_layout.width[list_layout.number++] = 10;
+   
+   list_layout = (listEntry *) XtCalloc(1, sizeof(listEntry));
+   list_layout->number = 0;
+   list_layout->field[list_layout->number] = nauthor;
+   list_layout->width[(list_layout->number)++] = 30;
+   list_layout->field[list_layout->number] = ntitle; 
+   list_layout->width[(list_layout->number)++] = 50;
+   list_layout->field[list_layout->number] = nyear; 
+   list_layout->width[(list_layout->number)++] = 5;
+   list_layout->field[list_layout->number] = ncategory; 
+   list_layout->width[(list_layout->number)++] = 10;
+   list_layout->field[list_layout->number] = -2;  /* BibTeX type */
+   list_layout->width[(list_layout->number)++] = 10;
+   list_layout->field[list_layout->number] = -1;  /* mainkey */
+   list_layout->width[(list_layout->number)++] = 10;
 
    for (i=0; i< MAX_BIBTEX_TYPES+1; i++){
       for (j=0; j< MAX_FIELDS; j++){
