@@ -38,6 +38,7 @@
 #define MAX_LINELEN        80
 #define MAX_ERRORSTRLEN    1000
 #define MAX_ERRLINELENGTH  80
+#define MAX_UEBERGABE      10000
 #define FLDINDENT          3
 #define CONTINDENT         15
 #define NEWLINEINDENT      7
@@ -216,7 +217,7 @@ typedef struct _CardListNode {
 
 /* structure to hold all widget pointers for all card types */
 typedef struct {
-   Widget wfield[2*(MAX_FIELDS-1)];
+   Widget wfield[2*MAX_FIELDS];
    Widget owntype,      owntypeL,
 	  mainkey,      mainkeyL,
 	  annote; 
@@ -538,6 +539,8 @@ void guwWarning(Errcode errcode);
 void guwNotice(Errcode errcode);
 void guwConfirmClose (Position x, Position y, 
                       XtCallbackProc p1, XtCallbackProc p2);
+void guwConfirmDelete (Position x, Position y, 
+                      XtCallbackProc p1, XtCallbackProc p2);
 void guwProgInfo (Widget w, XtPointer clientData, XtPointer callData);
 
 /* gui_help.c */
@@ -595,7 +598,7 @@ Errcode glbMakeBackup(String path);
 
 /* db_tree.c */
 Errcode dbtInsert (BibPtr bp, CardData *card);
-Errcode dbtDelete (int treeIdx, CardData *card);
+Errcode dbtDelete (int treeIdx, CardData *card, int *deleted);
 Errcode dbtSearch (int treeIdx, CardData **card);
 Errcode dbtMakeCard (CardData **card);
 Errcode dbtDeleteCard (CardData **card);
