@@ -52,6 +52,7 @@ extern Pixmap questPixmap, annoteIconPixmap;
 /* ------------------------- */
 static void annoteChanged (Widget w, XtPointer clientData, XtPointer callData);
 static void confirmCloseCard (CardPtr cp);
+static void confirmDeleteCard (CardPtr cp);
 static void confirmCloseAnnote (CardPtr cp);
 static void cancelQuitCmd (Widget w, XtPointer clientData, XtPointer callData);
 static void cardQuitOkCmd (Widget w, XtPointer clientData, XtPointer callData);
@@ -61,6 +62,7 @@ static Errcode annoteSave (CardPtr cp);
 static Errcode annoteClose (CardPtr cp); 
 static void annoteSaveCmd (Widget w, XtPointer clientData, XtPointer callData);
 static void annoteCloseCmd (Widget w, XtPointer clientData, XtPointer callData);
+static void DeleteOkCmd (Widget w, XtPointer clientData, XtPointer callData);
 
 
 /* exported variables */
@@ -305,9 +307,9 @@ String hlpstring;
        return;
        }
    if (cp->cd->mainkey==NULL)
-      sprintf(aw->shellName, "Annote: NEW");
+      sprintf(aw->shellName, "%s: NEW", glbFldToName(nannote));
    else
-      sprintf(aw->shellName, "Annote: %s", cp->cd->mainkey);
+      sprintf(aw->shellName, "%s: %s", glbFldToName(nannote), cp->cd->mainkey);
    aw->annoteShell = XtVaCreatePopupShell("AnnoteShell",
 	       topLevelShellWidgetClass, topLevel,
 	       XtNtitle, aw->shellName,
@@ -356,6 +358,30 @@ BibPtr bp = (BibPtr)cp->bp;
 CardDataList cl, clp;
 Errcode status;
 
+   confirmDeleteCard(cp);
+   return;
+}
+
+/*********************************************************************/
+/* DeleteOkCmd:                                                      */
+/*    Callback function "OK" button                                  */
+/*********************************************************************/
+static void 
+DeleteOkCmd (Widget w, XtPointer clientData, XtPointer callData)
+{
+Widget shell = (Widget)clientData;
+CardPtr cp;
+CardDataList cl, clp;
+BibPtr bp;
+Errcode status;
+int del_erg;
+
+   /* remove confirm shell */
+   XtPopdown(shell);
+
+   cp = gcp;
+   bp = (BibPtr)cp->bp;
+   
    /* remove card from list of cards for list window */
    if (gulListWinExists(bp)){
     if (cp->cd->mainkey!=NULL){
@@ -396,11 +422,17 @@ Errcode status;
       guwError(status);
    
    /* delete card from data tree */
-   if ((status = dbtDelete(bp->treeIdx, cp->cd)) != DBT_OK) {
+   if ((status = dbtDelete(bp->treeIdx, cp->cd, &del_erg)) != DBT_OK) {
       guwError(status);
       return;
    }
-   bp->changed = TRUE;
+   if (del_erg)
+     bp->changed = TRUE;
+   gcp = NULL;
+
+   /* enable menus */
+   XtSetSensitive(mainMenu, TRUE);
+   gubSetSensitive(NULL, TRUE);
    
 
 }
@@ -420,10 +452,11 @@ CardDataList cl, clp;
 Errcode status;
 XawTextBlock textblock;
 CardData *hcard = NULL;
+int del_erg;
 String str;
 
    /* delete old card from data tree */
-   if ((status = dbtDelete(bp->treeIdx, cp->cd)) != DBT_OK) {
+   if ((status = dbtDelete(bp->treeIdx, cp->cd, &del_erg)) != DBT_OK) {
       guwError(status);
       return;
    }
@@ -685,6 +718,29 @@ CardPtr cp = (CardPtr)clientData;
 cp->aw->changed = TRUE;
 }
 
+
+/*********************************************************************/
+/* confirmDeleteCard:                                                */
+/*    Opens dialogbox for user to confirm closing without saving     */
+/*********************************************************************/
+static void
+confirmDeleteCard (CardPtr cp)
+{
+Position dx, dy, x, y;
+
+   XtVaGetValues(desktop,
+                 XtNx, &dx,
+                 XtNy, &dy, NULL);
+   XtTranslateCoords(cp->cw->cardDesk,
+                     (Position)dx + SUBWIN_MARGIN,
+                     (Position)dy + SUBWIN_MARGIN,
+                     &x, &y);
+   gcp = cp;
+   guwConfirmDelete(x,y,cancelQuitCmd,DeleteOkCmd);
+}
+
+
+
 /*********************************************************************/
 /* confirmCloseCard:                                                 */
 /*    Opens dialogbox for user to confirm closing without saving     */
