@@ -289,6 +289,7 @@ cseEditMacros (BibPtr bp)
 {
 Errcode status;
 int fh;
+char *tempName;
 
    /* window opened already? */
    if (gueMacroWinExists(bp)) {
@@ -302,7 +303,9 @@ int fh;
    /* open new temp file? */
    if (bp->macrofile == NULL) {
 #ifdef NO_TEMPNAM
-      bp->macrofile = (char *)tmpnam(NULL);
+      tempName = (char *)tmpnam(NULL);
+      bp->macrofile = (char *)XtMalloc(strlen(tempName)+1);
+      strcpy(bp->macrofile,tempName);
 #else
       bp->macrofile = (char *)tempnam(NULL, NULL);
 #endif
