@@ -107,7 +107,7 @@ int     dbtSearchAllUserFld(UserFld **list, char *str);
 int     dbtSearchUserFld(UserFld **list, UserFld **reglist);
 Boolean Insert(int treeIdx, AvlNode **tree, CardData *card, int *h);
 Boolean Search(AvlNode *tree, CardData **card);
-Boolean Delete(int treeIdx, AvlNode **tree, CardData *card);
+Boolean Delete(int treeIdx, AvlNode **tree, CardData *card, int *deleted);
 Errcode MakeListNode(ListNode **list);
 Errcode ListAppend(ListNode **list, String word);
 Errcode MakeCardListNode(CardListNode **list);
@@ -679,14 +679,16 @@ Boolean del_item(int treeIdx, AvlNode **tree)
  *          TRUE  balancing required
  *          FALSE no further balancing required
  */
-Boolean Delete(int treeIdx, AvlNode **tree, CardData *card)
+Boolean Delete(int treeIdx, AvlNode **tree, CardData *card, int *deleted)
 {
     int result;
+    int del_erg;
 
     if ((*tree) == NULL) {
         /*
          * key not in tree
          */
+        *deleted = 0;
         return FALSE;
     }
     else if ((result = 
@@ -694,24 +696,29 @@ Boolean Delete(int treeIdx, AvlNode **tree, CardData *card)
         /*
          * key found
          */
+        *deleted = 1;
         return del_item(treeIdx, tree);
     }
     else if (result < 0) {
         /*
          * key could be in left sub-tree
          */
-        if (Delete(treeIdx, &((*tree)->left), card)) {
+        if (Delete(treeIdx, &((*tree)->left), card, &del_erg)) {
+	    *deleted = del_erg;
             return left_path_balance(treeIdx, tree);
         }
+	*deleted = del_erg;
         return FALSE;
     }
     else {
         /*
          * key could be in right sub-tree
          */
-        if (Delete(treeIdx, &((*tree)->right), card)) {
+        if (Delete(treeIdx, &((*tree)->right), card, &del_erg)) {
+	    *deleted = del_erg;
             return right_path_balance(treeIdx, tree);
         }
+	*deleted = del_erg;
         return FALSE;
     }
 }
@@ -1466,13 +1473,16 @@ Errcode dbtInsert(BibPtr bp, CardData *card)
 /* card wird aus dem AVL-Baum mit dem Index treeIdx geloescht        */
 /*********************************************************************/
 
-Errcode dbtDelete(int treeIdx, CardData *card)
-{
+Errcode dbtDelete(int treeIdx, CardData *card, int *deleted)
+{ int del_erg;
   Boolean err;
   
-  if (TreeRoots[treeIdx] == (AvlNode *)1) 
+  if (TreeRoots[treeIdx] == (AvlNode *)1) {
+     *deleted = 0;
      return DBT_OK;   /* nur vorerst */
-  err = Delete(treeIdx, &TreeRoots[treeIdx], card);
+     }
+  err = Delete(treeIdx, &TreeRoots[treeIdx], card, &del_erg);
+  *deleted = del_erg;
   return DBT_OK;   /* nur vorerst */
 }
 
@@ -2000,11 +2010,11 @@ void get_name(CardData  *card, int fieldnr)
 
     i = 0;
     inbracket=0;
-    name[i] = strtok(entry, semicolon);
+    name[i] = (char *) strtok(entry, semicolon);
     while ((name[i] != NULL) && (i<10))
        {
         i++;
-        name[i] = strtok(NULL, semicolon);
+        name[i] = (char *) strtok(NULL, semicolon);
        }
     for (j=0; j<i; j++)
       {
@@ -2030,8 +2040,8 @@ void get_name(CardData  *card, int fieldnr)
        else
           {
            /* get firstname and surname in right order */
-           p_surname = strtok (name[j], comma);
-           p_firstname = strtok (NULL, comma);
+           p_surname = (char *) strtok (name[j], comma);
+           p_firstname = (char *) strtok (NULL, comma);
            mystrcat (card->authorsort, p_surname);
            mystrcat (card->authorsort, p_firstname);
           }
