@@ -540,7 +540,7 @@ char tmpfile[MAX_FILEPATHLEN];
            i++;
            sprintf(tmpfile, "%s.bak.%d", path, i);
            }
-   sprintf(sysStr, "mv -f %s %s.bak.%d", path, path, i);
+   sprintf(sysStr, "cp -f %s %s.bak.%d", path, path, i);
    if (access(path, F_OK) == 0) {
       system(sysStr);
       return(OK);
@@ -784,6 +784,10 @@ int glbContIllegalChar(char *dateiName)
  int inh;
 
  dptr = fopen(dateiName, "r");
+
+ if (dptr == NULL)
+   return 0;
+
  while ( ((inh = getc(dptr)) != EOF) && isascii(inh) ) ;
    
  fclose(dptr); 
