@@ -64,6 +64,210 @@ extern char sort_field[];
 
 /* local global variables */
 /* ------------------------- */
+static XtTranslations trans;
+
+static char trans_string[] =
+   "<Key>Tab:   forward_focus()\n\
+   <Key>Escape: backward_focus()\n\
+   <Btn3Down>,<Btn3Up>: set_focus()";
+
+static void forward_focus();
+static void backward_focus();
+static void set_focus();
+
+static XtActionsRec actions[] = {
+   "forward_focus", forward_focus,
+   "backward_focus", backward_focus,
+   "set_focus", set_focus,
+};
+
+#ifdef ACTION_PROBLEM
+static int first_in = 1;
+#endif
+
+/*********************************************************************/
+/* forward_focus:                                                    */
+/*    moves the focus of a field to the next field                   */
+/*********************************************************************/
+static void forward_focus(Widget w)
+{
+ BibPtr bp;
+ CardPtr cp;
+ CardWidgetsPtr cwp;
+ int i;
+ Pixel back, fore;
+
+ bp = glbFirstBibListEl();
+ while (bp!=NULL){
+    cp = glbFirstCardListEl(bp);
+    while (cp!=NULL){
+       XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
+       XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
+       cwp = &cp->cw->ct.cw;
+       if (w == cwp->mainkey){
+          XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
+          if (cwp->owntype){
+             XtSetKeyboardFocus(XtParent(w), cwp->owntype);
+             XtVaSetValues(cwp->owntype, XtNborderColor, back, NULL);
+             return;
+             }
+          else {
+             for (i=0; i< MAX_FIELDS; i++)
+            	if (cwp->wfield[2*i+1]){
+                XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
+	        return;
+	        }
+             if (i == MAX_FIELDS){
+               XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
+               XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+	       return;
+	       }
+             }
+          }
+       if (w == cwp->owntype){
+          XtVaSetValues(cwp->owntype, XtNborderColor, fore, NULL);
+          for (i=0; i< MAX_FIELDS; i++)
+             if (cwp->wfield[2*i+1]){
+                XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
+                XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                return;
+                }
+          if (i == MAX_FIELDS){
+             XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+             XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
+	     return;
+	     }
+       }
+       for (i=0; i< MAX_FIELDS; i++)
+         if (w == cwp->wfield[2*i+1]){
+            XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, fore, NULL);
+            for (i=i+1; i< MAX_FIELDS; i++)
+              if (cwp->wfield[2*i+1]){
+                 XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
+                 XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                 return;
+                 }
+            if (i == MAX_FIELDS){
+               XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
+               XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+               return;
+               }
+         }
+       cp = glbNextCardListEl(bp,cp);
+       }
+    bp = glbNextBibListEl(bp);
+    }
+}
+
+/*********************************************************************/
+/* forward_focus:                                                    */
+/*    moves the focus to the previous field                          */
+/*********************************************************************/
+static void backward_focus(Widget w)
+{
+ BibPtr bp;
+ CardPtr cp;
+ CardWidgetsPtr cwp;
+ int i;
+ Pixel back, fore;
+
+ bp = glbFirstBibListEl();
+ while (bp!=NULL){
+    cp = glbFirstCardListEl(bp);
+    while (cp!=NULL){
+      XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
+      XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
+      cwp = &cp->cw->ct.cw;
+      if (w == cwp->mainkey){
+         XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
+         for (i=MAX_FIELDS-1; i>=0; i--)
+            if (cwp->wfield[2*i+1]){
+               XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+               XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
+               return;
+               }
+         if (i < 0){
+            if (cwp->owntype){
+               XtVaSetValues(cwp->owntype, XtNborderColor, back, NULL);
+               XtSetKeyboardFocus(XtParent(w), cwp->owntype);
+               return;
+               }
+            else{
+               XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
+               XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
+       	       return;
+     	       }
+            }
+         }
+      if (w == cwp->owntype){
+         XtVaSetValues(cwp->owntype, XtNborderColor, fore, NULL);
+         XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
+         XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+         return;
+         }
+      for (i=MAX_FIELDS-1; i>=0; i--)
+         if (w == cwp->wfield[2*i+1]){
+            XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, fore, NULL);
+            for (i=i-1; i>=0; i--)
+               if (cwp->wfield[2*i+1]){
+                  XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
+                  XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                  return;
+                  }
+            if (i < 0){
+               if (cwp->owntype){
+                  XtSetKeyboardFocus(XtParent(w), cwp->owntype);
+                  XtVaSetValues(cwp->owntype, XtNborderColor, back, NULL);
+                  return;
+                  }
+               else{
+                  XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
+                  XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+                  return;
+                  }
+            }
+         }
+       cp = glbNextCardListEl(bp,cp);
+       }
+    bp = glbNextBibListEl(bp);
+    }
+}
+
+/*********************************************************************/
+/* set_focus:                                                        */
+/*    moves the focus to the field in which the left mouse           */
+/*    button is pressed                                              */
+/*********************************************************************/
+static void set_focus(Widget w)
+{
+ BibPtr bp;
+ CardPtr cp;
+ CardWidgetsPtr cwp;
+ int i;
+ Pixel back, fore;
+
+ bp = glbFirstBibListEl();
+ while (bp!=NULL){
+    cp = glbFirstCardListEl(bp);
+    while (cp!=NULL){
+       cwp = &cp->cw->ct.cw;
+       XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
+       XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
+       XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
+       if (cwp->owntype)
+          XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
+       for (i=0; i< MAX_FIELDS; i++)
+          if (cwp->wfield[2*i+1])
+             XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor,
+		fore, NULL);
+       cp = glbNextCardListEl(bp,cp);
+       }
+    bp = glbNextBibListEl(bp);
+    }
+ XtSetKeyboardFocus(XtParent(w), w);
+ XtVaSetValues(w, XtNborderColor, back, NULL);
+}
 
 
 /*********************************************************************/
@@ -74,6 +278,20 @@ Errcode
 gucOpenCardWin (BibPtr bp, CardPtr cp, Boolean isNew)
 {
 CardWinPtr cw;
+CardWidgetsPtr cwp;
+Pixel fore, back;
+  
+   #ifdef ACTION_PROBLEM
+   if (first_in){
+   #endif
+   XtAppAddActions(XtWidgetToApplicationContext(topLevel), actions,
+		  XtNumber(actions));
+   #ifdef ACTION_PROBLEM
+   first_in = 0;
+   }
+   #endif
+
+   trans = XtParseTranslationTable(trans_string);
 
    /* allocate memory for new element of window list */
    if ((cw = (CardWinPtr) XtCalloc(1, sizeof(CardWin))) == NULL) {
@@ -114,7 +332,8 @@ CardWinPtr cw;
    cw->userDef = XtVaCreateManagedWidget("userDef", 
 	           commandWidgetClass, cw->cmdBox, NULL);
    cw->annote = XtVaCreateManagedWidget("annote", 
-	           commandWidgetClass, cw->cmdBox, NULL);
+	           commandWidgetClass, cw->cmdBox,
+		   XtNlabel, glbFldToName(nannote), NULL);
    cw->delete = XtVaCreateManagedWidget("delete", 
 	          commandWidgetClass, cw->cmdBox, NULL);
    cw->change = XtVaCreateManagedWidget("save", 
@@ -138,7 +357,7 @@ CardWinPtr cw;
 
    /* create card window desktop */
    cw->cardDesk = XtVaCreateManagedWidget("carddesk",  
-	            formWidgetClass, cw->cardWin);
+	            formWidgetClass, cw->cardWin, NULL);
    cw->cardFlds = XtVaCreateManagedWidget(glbTypeToName(cp->cd->cardtype), 
 	            formWidgetClass, cw->cardDesk, NULL);
 
@@ -164,8 +383,14 @@ CardWinPtr cw;
 
    /* build only widgets for specific card type */
    createWidgets(bp, cp);
+   cwp = &cp->cw->ct.cw;
 
    XtPopup(cw->cardShell, XtGrabNone);
+   XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
+   XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
+   XtSetKeyboardFocus(cw->cardFlds, cwp->mainkey);      
+   XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+
    return(OK);
 }
 
@@ -689,7 +914,12 @@ CardWidgetsPtr cwp = &cp->cw->ct.cw;	/* ptr to widget ids */
 CardDataPtr cdp = cp->cd;		/* ptr to real card data */
 Widget card = cp->cw->cardFlds;		/* parent widget */
 Widget aktwidget;
-FieldName i;
+int i;
+
+   for (i=0; i<MAX_FIELDS; i++){
+      cwp->wfield[2*i]   = NULL;
+      cwp->wfield[2*i+1] = NULL;
+      }
 
    cdp->annoteChanged = FALSE;
    cwp->mainkeyL = 	XtVaCreateManagedWidget("fieldLabel", 
@@ -703,6 +933,7 @@ FieldName i;
 		  	  XtNtop, XtChainTop, 
 		  	  XtNfromHoriz, cwp->mainkeyL, 
 			  NULL);
+   XtOverrideTranslations(cwp->mainkey, trans);
    aktwidget = cwp->mainkey;
    if (cdp->cardtype == MAX_BIBTEX_TYPES){
       cwp->owntypeL = 	XtVaCreateManagedWidget("fieldLabel", 
@@ -715,6 +946,7 @@ FieldName i;
 		  	  XtNstring, cdp->cardtypestr, 
 		    	  XtNfromVert, aktwidget, 
 		  	  XtNfromHoriz, cwp->owntypeL, NULL);
+      XtOverrideTranslations(cwp->owntype, trans);
       aktwidget = cwp->owntype;
    }
    for (i=0; i<max_fields; i++) {
@@ -729,6 +961,7 @@ FieldName i;
 		  	  XtNstring, cdp->field[i], 
 		    	  XtNfromVert, aktwidget, 
 		  	  XtNfromHoriz, cwp->wfield[2*i], NULL);
+         XtOverrideTranslations(cwp->wfield[2*i+1], trans);
       if (isrequiredfield(i, cdp->cardtype))
          XtVaSetValues(cwp->wfield[2*i+1], XtNborderWidth, 3, NULL);
       aktwidget = cwp->wfield[2*i+1];
