@@ -113,7 +113,7 @@ int fld_indent, cont_indent, newline_indent, max_linelen;
 char *actual_path;
 extern char *style_file;
 extern int sortedby;
-extern listEntry list_layout;
+extern listEntry *list_layout;
 
 extern char requiredfields[MAX_BIBTEX_TYPES+1][MAX_FIELDS];
 extern char standardfields[MAX_BIBTEX_TYPES+1][MAX_FIELDS];
@@ -215,7 +215,7 @@ char processLine;
               /*      curMode = getCfgFileTag(cfgLine); */
                     curMode = getCfgFileTag(cfgp);
 		    if (curMode == listFieldTags)
-                       list_layout.number = 0;
+                       list_layout->number = 0;
                     if (curMode != illegalTag)
                        continue; 
                     processLine = TRUE;
@@ -966,11 +966,11 @@ int width, fieldnr;
       return(OK);
       }
    if (strcmp(field, "mainkey") == 0)
-      list_layout.field[list_layout.number] = -1;
+      list_layout->field[list_layout->number] = -1;
    else if (strcmp(field, "cardtype") == 0)
-      list_layout.field[list_layout.number] = -2;
+      list_layout->field[list_layout->number] = -2;
    else if ((fieldnr = glbNameToField(field)) != -1)
-      list_layout.field[list_layout.number] = fieldnr;
+      list_layout->field[list_layout->number] = fieldnr;
    else { 
       if (max_fields == MAX_FIELDS){
 	    fprintf(stderr,
@@ -979,11 +979,11 @@ int width, fieldnr;
 	    }
       fieldNames[max_fields] = XtCalloc(strlen(field)+1, sizeof(char));
       strcpy(fieldNames[max_fields], strlower(field));
-      list_layout.field[list_layout.number] = max_fields;
+      list_layout->field[list_layout->number] = max_fields;
       max_fields++;
    }
-   list_layout.width[list_layout.number] = width;
-   list_layout.number++;
+   list_layout->width[list_layout->number] = width;
+   list_layout->number++;
    
    return(OK);
 }
